#
# spec file for package python-psycopg-c
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-psycopg-c
# This needs to upgraded in lockstep with python-psycopg
Version:        3.1.15
Release:        1.1
Summary:        PostgreSQL database adapter for Python -- C optimisation distribution
License:        LGPL-3.0-only
URL:            https://psycopg.org/psycopg3/
Source:         https://files.pythonhosted.org/packages/source/p/psycopg-c/psycopg-c-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 49.2.0}
BuildRequires:  %{python_module tomli >= 2.0.1}
BuildRequires:  %{python_module wheel >= 0.37}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  postgresql15-server-devel
BuildRequires:  python-rpm-macros
%python_subpackages

%description
PostgreSQL database adapter for Python -- C optimisation distribution

%prep
%autosetup -p1 -n psycopg-c-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# Tested in python-psycopg

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/psycopg_c
%{python_sitearch}/psycopg_c-%{version}.dist-info

%changelog
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.15:
  * Fix use of service in connection string
  * Fix async connection to hosts resolving to multiple IP
    addresses
  * Respect the PGCONNECT_TIMEOUT environment variable to
    determine the connection timeout.
  * Psycopg 3.1.14
  * Fix interaction with gevent (ticket #527).
  * Add support for PyPy (ticket #686).
* Fri Nov 24 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.1.13:
  * Raise DataError instead of whatever internal failure trying to
    dump a time object with with a tzinfo specified as ZoneInfo
    (ambiguous offset, see ticket #652).
  * Handle gracefully EINTR on signals instead of raising
    InterruptedError, consistently with PEP 475 guideline
    (ticket #667).
  * Fix support for connection strings with multiple hosts/ports
    and for the load_balance_hosts connection parameter
    (ticket #674).
  * Fix memory leak receiving notifications in Python
    implementation (ticket #679).
- Update to 3.1.12:
  * Fix possible hanging if a connection is closed while querying
    (ticket #608).
  * Fix memory leak when register_*() functions are called
    repeatedly (ticket #647).
  * Release Python 3.12 binary packages.
- Update to 3.1.11:
  * Avoid caching the parsing results of large queries to avoid
    excessive memory usage (ticket #628).
  * Fix integer overflow in C/binary extension with OID > 2^31
    (ticket #630).
  * Fix loading of intervals with days and months or years
    (ticket #643).
  * Work around excessive CPU usage on Windows (reported in
    ticket #645).
  * Fix building on Solaris and derivatives (ticket #632).
  * Fix possible lack of critical section guard in
    async executemany().
  * Fix missing pipeline fetch in async scroll().
  * Build binary packages with libpq 15.4, which allows
    group-readable permissions on the SSL certificate on the client
    (ticket #528).
- Update to 3.1.10
  * Allow JSON dumpers to dump bytes directly instead of str, for
    better compatibility with libraries like orjson and msgspec
    (ticket #569)
  * Fix prepared statement cache validation when exiting pipeline
    mode (or executemany()) in case an error occurred within the
    pipeline (ticket #585).
  * Fix connect() to avoid “leaking” an open PGconn attached to
    the OperationalError in case of connection failure.
    Error.pgconn is now a shallow copy of the real libpq
    connection, and the latter is closed before the exception
    propagates (ticket #565).
  * Fix possible (ignored) exception on objects deletion
    (ticket #591).
  * Don’t clobber a Python exception raised during COPY FROM with
    the resulting QueryCanceled raised as a consequence
    (ticket #593).
  * Fix resetting Connection.read_only and deferrable to their
    default value using None (ticket #612).
  * Add support for Python 3.12.
* Wed Jul 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 3.1.9
